@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-citeproc
 version: 0.9.1.1
-id: pandoc-citeproc-0.9.1.1-1b097fc52b987e4e8df58ce101963d64
-key: pando_KUchKCHDpmI80Y72HV5IEd
+id: pandoc-citeproc-0.9.1.1-73264de714e378873dab1ffec883ac19
+key: pando_0vklpJfJSmVLgKqc03sgXt
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: https://github.com/jgm/pandoc-citeproc
@@ -42,7 +42,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 data-dir: /usr/share/pandoc-citeproc
-hs-libraries: HSpandoc-citeproc-0.9.1.1-KUchKCHDpmI80Y72HV5IEd
+hs-libraries: HSpandoc-citeproc-0.9.1.1-0vklpJfJSmVLgKqc03sgXt
 depends:
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -54,7 +54,7 @@ depends:
     hs-bibutils-5.5-91f8c150a94b021e3f1d7580075e1ca0
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
+    pandoc-1.17.0.3-0fb83bbdb463f00b380a74b829ef3d80
     pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
@@ -66,8 +66,8 @@ depends:
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
-    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
+    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
+    yaml-0.8.16-456c08a298c79f92e1296e690079eee9
 haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
 haddock-html: /usr/share/doc/pandoc-citeproc/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
